==> todotask2.0.1.zip: todotask2/app/views/info/todotask.php <==
<?php
	// ページ描画
	// ヘッダ
	require_once(TODOTASK_VIEW_DIR.'/common/header.inc.php');
?>


<div align="center">

<div class="noticediv" style="text-align:left;">
<h1>TODOTASK...とは。</h1>
<p>
トドタスクはやらなければならないこと(To Do)をリスト化して管理するためのプログラムです。<br>


To Doを管理することにより日常の業務や個人的な備忘録としてお役立ていただけます。<br>
プログラムそのものを利用することにより、「何をやらなければいけないんだったかな？」と
見失いがちな目標を明確に「実行できる」レベルのタスクに落とし込むことにより、
自分やチームがやらなければならない行動を「実行する」のに役立ちます。<br>
特に業務で使うことを念頭に設計していますのでプロジェクトマネジメントツールとしてご活用ください。
</p>

<p>

</p>


<h2>TODOTASKはOSSです</h2>
<p>
TODOTASKは<a href="http://ja.wikipedia.org/wiki/BSD%E3%83%A9%E3%82%A4%E3%82%BB%E3%83%B3%E3%82%B9" target="_blank">修正BSDライセンス</a>に準拠するライセンス形態を採用している
OSS(オープンソースシステム)です。
ソースを公開するだけでなく、このソースを元に改変し再配布、使用することを許可しています。<br>
これは社内業務に使用する際にカスタマイズなどを許可しているということです。
ウェブシステム上では守秘義務内容に基づいた運用は困難ですので、自社にシステムを導入するなどして業務効率の向上に役立ててください。<br><br>

これらの要項については<a href="<?php echo INFO_TERMOFUSE_PAGE; ?>">利用規約</a>に詳細を記述していますのでそちらをご覧ください。<br>

<a href="<?php echo TODOTASK_SRC_URL; ?>" target="_blank">トドタスクのソース配布</a>はSourceForge.JPのプロジェクト: todotaskから最新版を手にいれることができます。
また<a href="http://www.todotask.com/" target="_blank">トドタスクのサービスページ</a>においても利用することができます。

</p>


<h2>ビジネスユース</h2>
<p>
トドタスクはビジネスユースにおいても無料でご利用になることができます。<br><br>

社内導入サポートが必要であったり、既存のシステムと連携を予定されている法人さまはご相談ください。
出張導入や導入のサポート、カスタマイズのお見積りも致します。
<br><br>
</p>


参考価格：<br>
<ul>
<li>レンタルサーバーへの設置代行：20万</li>
<li>出張イントラ設置：別途お見積り</li>
<li>カスタマイズ、他システムとの連携：別途お見積り</li>
<li>サポート(メールプラン)：年間24万</li>
</ul>
<br>

<p>
※これらの値段は参考価格です。TODOTASKはOSSのビジネスモデル実証実験も兼ねています。
価格決定についてご意見や参考意見をお寄せいただければ幸いです。<br>
※当社繁忙期には対応しかねる場合もございますのでご了承ください。<br>
※これらの業務をお手伝いしていただける全国のSE,PG,WEBデザイナーの方もご連絡いただければと思います。
本案件に関らず分散開発の体制を確立し競業できたらと考えております。
<br><br>

</p>


<h2>製作者について</h2>
<p>
TODOTASKは<a href="http://www.hagurachaya.com/" target="_blank">紅茶ハーブティーの専門店 はぐら茶屋</a>による制作になります。<br>
茶葉の小売、喫茶などの業務をおこなっている一方、その他にシステム受託開発などのソリューション業務もおこなっております。ちょっとだけ特殊なSOHOです。<br><br>

<a href="http://www.city.mitaka.tokyo.jp/a002/p004/g02/d00400002.html" target="_blank">
三鷹はインテリジェントシティとして世界で1番の都市</a>に認定されたこともある世界でも有数のIT先進都市です。
日本でのSOHO発祥も三鷹かららしいのでそのような事業形態も盛んです。
またまだあまり各地で例をみない<a href="http://www.mitaka-ict.jp/" target="_blank">
ICT事業者協会</a>のような横のつながりもしっかりしています。
そんなわけで、環境も整っているので三鷹で茶屋をつくってお茶のみながらプログラム書いたりしているというような感じです。
<br>
<br>ちなみに私が飲んでいる
<a href="http://store.shopping.yahoo.co.jp/hagurachaya/index.html" target="_blank">美味しい紅茶やハーブなどの茶葉を小売するネットショップ</a>もありますので、是非ご利用ください。

<br>
<br>
お問合わせはメール、	
<script type="text/javascript"><!-- 
document.write('<a href="mai' + 'lto:&#105;&#11' + '0;&#102;&#111;&#64;&#116;&#111;&#100;&#111;&#116;&#97;&#115;&#107;&#46;&#99;&#111;&#109;">&#105;&#11' + '0;&#102;&#111;&#64;&#116;&#111;&#100;&#111;&#116;&#97;&#115;&#107;&#46;&#99;&#111;&#109;</a>'); 
--></script>
もしくはお電話にてお問合わせください。<br>
(東京三鷹)0422-48-8937<br>
店舗の電話と共用のためコアタイムには対応しかねることがございます。
</p>

<br>
<br>





</div>


<br><br><br>
<a href="<?php echo $this->backurl; ?>">もどる</a>
<br><br>
</div>


<?php
	// フッター
	include_once(TODOTASK_VIEW_DIR.'/common/footer.inc.php');

?>

==> todotask2.0.2.zip: todotask2/app/views/info/todotask.php <==
<?php
	// ページ描画
	// ヘッダ
	require_once(TODOTASK_VIEW_DIR.'/common/header.inc.php');
?>


<div align="center">

<div class="noticediv" style="text-align:left;">
<h1>TODOTASK...とは。</h1>
<p>
トドタスクはやらなければならないこと(To Do)をリスト化して管理するためのプログラムです。<br>


To Doを管理することにより日常の業務や個人的な備忘録としてお役立ていただけます。<br>
プログラムそのものを利用することにより、「何をやらなければいけないんだったかな？」と
見失いがちな目標を明確に「実行できる」レベルのタスクに落とし込むことにより、
自分やチームがやらなければならない行動を「実行する」のに役立ちます。<br>
特に業務で使うことを念頭に設計していますのでプロジェクトマネジメントツールとしてご活用ください。
</p>

<p>

</p>


<h2>TODOTASKはOSSです</h2>
<p>
TODOTASKは<a href="http://ja.wikipedia.org/wiki/BSD%E3%83%A9%E3%82%A4%E3%82%BB%E3%83%B3%E3%82%B9" target="_blank">修正BSDライセンス</a>に準拠するライセンス形態を採用している
OSS(オープンソースシステム)です。
ソースを公開するだけでなく、このソースを元に改変し再配布、使用することを許可しています。<br>
これは社内業務に使用する際にカスタマイズなどを許可しているということです。
ウェブシステム上では守秘義務内容に基づいた運用は困難ですので、自社にシステムを導入するなどして業務効率の向上に役立ててください。<br><br>

これらの要項については<a href="<?php echo INFO_TERMOFUSE_PAGE; ?>">利用規約</a>に詳細を記述していますのでそちらをご覧ください。<br>

<a href="<?php echo TODOTASK_SRC_URL; ?>" target="_blank">トドタスクのソース配布</a>はSourceForge.JPのプロジェクト: todotaskから最新版を手にいれることができます。
またサービス利用については<a href="http://www.todotask.com/" target="_blank">www.todotask.com</a>においても利用することができます。

</p>


<h2>ビジネスユース</h2>
<p>
トドタスクはビジネスユースにおいても無料でご利用になることができます。<br><br>

社内導入サポートが必要であったり、既存のシステムと連携を予定されている法人さまはご相談ください。
出張導入や導入のサポート、カスタマイズのお見積りも致します。
<br><br>
</p>


参考価格：<br>
<ul>
<li>レンタルサーバーへの設置代行：20万</li>
<li>出張イントラ設置：別途お見積り</li>
<li>カスタマイズ、他システムとの連携：別途お見積り</li>
<li>サポート(メールプラン)：年間24万</li>
</ul>
<br>

<p>
※これらの値段は参考価格です。TODOTASKはOSSのビジネスモデル実証実験も兼ねています。
価格決定についてご意見や参考意見をお寄せいただければ幸いです。<br>
※当社繁忙期には対応しかねる場合もございますので時期に余裕を持ってご相談ください。<br>
※これらの業務をお手伝いしていただける全国のSE,PG,WEBデザイナーの方もご連絡いただければと思います。
本案件に関らず分散開発の体制を確立し競業できたらと考えております。<br>
<br>

</p>


<h2>製作者について</h2>
<p>
TODOTASKは<a href="http://www.hagurachaya.com/" target="_blank">紅茶ハーブティーの専門店 はぐら茶屋</a>による制作になります。<br>
茶葉の小売、喫茶などの業務をおこなっている一方、その他にシステム受託開発などのソリューション業務もおこなっております。すこしだけ特殊なSOHOです。<br><br>

<a href="http://www.city.mitaka.tokyo.jp/a002/p004/g02/d00400002.html" target="_blank">
三鷹はインテリジェントシティとして世界で1番の都市</a>に認定されたこともある世界でも有数のIT先進都市です。
日本でのSOHO発祥も三鷹からでそのような小規模事業形態も盛んです。
またまだあまり各地で例をみない<a href="http://www.mitaka-ict.jp/" target="_blank">ICT事業者協会</a>のような横のつながりもあり、
<br>
<ul>
<li>・案件情報の共有</li>
<li>・定期的なセミナーなど学習機会の創出</li>
<li>・地域に根ざした産業の育成や地元企業との交流</li>
<li>・地元商工会と連携し新人研修やセキュリティ講習など</li>
</ul>
このような取り組みをおこなっております。
そんなわけで、環境も整っているので三鷹で茶屋をつくってお茶のみながらプログラム書いたりしているというような感じです。
<br>
<br>ちなみに<a href="http://store.shopping.yahoo.co.jp/hagurachaya/index.html" target="_blank">美味しい紅茶やハーブなどの茶葉を小売するネットショップ</a>もありますので、是非ご利用ください。
TODOTASKのバグ修正やちょっとしたアイコンの制作などちょっとしたご貢献いただけた方でご希望の方には紅茶のご進呈も検討しております。

<br>
<br>
お問合わせはメール、	
<script type="text/javascript"><!-- 
document.write('<a href="mai' + 'lto:&#105;&#11' + '0;&#102;&#111;&#64;&#116;&#111;&#100;&#111;&#116;&#97;&#115;&#107;&#46;&#99;&#111;&#109;">&#105;&#11' + '0;&#102;&#111;&#64;&#116;&#111;&#100;&#111;&#116;&#97;&#115;&#107;&#46;&#99;&#111;&#109;</a>'); 
--></script>
もしくはお電話にてお問合わせください。<br>
(東京三鷹)0422-48-8937<br>
店舗の電話と共用のためコアタイムには対応しかねることがございます。
</p>

<br>
<br>





</div>


<br><br><br>
<a href="<?php echo $this->backurl; ?>">もどる</a>
<br><br>
</div>


<?php
	// フッター
	include_once(TODOTASK_VIEW_DIR.'/common/footer.inc.php');

?>
